export class Main extends Indicator {

    constructor() {
        super();

        this.addInput("Period", InputType.int, 13, {
            min: 2
        });
        this.addInput("Averaging", InputType.Averaging, Averaging.Simple);
        this.addInput("AppliedPrice", InputType.AppliedPrice, AppliedPrice.Close);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffer = this.addBuffer();
    }

    onInit() {
        let {Period, Averaging} = this.getInputs(),
            drawBegin = Period - 1,
            shortName;

        switch (Averaging) {
            case Averaging.Exponential:
                shortName = "EMA";
                drawBegin = 0;
                break;
            case Averaging.Smoothed:
                shortName = "SMMA";
                break;
            case Averaging.LinearWeighted:
                shortName = "LWMA";
                break;
            default :
                shortName = "SMA";
        }

        this.buffer
            .setShape(Shape.Line)
            .setDrawingStyle(DrawingStyle.Solid)
            .setColor(Color.Red)
            .setDigits(Current.Digits)
            .setDrawBegin(drawBegin)
            .setShortName(shortName + "(" + Period + ")");
    }

    async onUpdate() {
        let list, {Period, Averaging, AppliedPrice, PriceType} = this.getInputs();

        list = await Indicators.MA(Current.Symbol, Current.TimeFrame, Period, 0, Averaging, AppliedPrice, PriceType);
        this.buffer.fill(list);
    }
}
